@@ -134,7 +134,7 @@ def add_images_to_existing_project(session, projnumber):
                 print("Sorry, I didn't understand that? Did you type a number?")
                 continue
             else:
-                print(f"Number of addtional MovingImage: {additional_moving}")
+                print(f"Number of additional MovingImage: {additional_moving}")
                 break
 
         if additional_moving > 0:
@@ -198,7 +198,7 @@ def add_images_to_existing_project(session, projnumber):
                                )
 
         num_moving = num_existing_moving + additional_moving
-        for i in range(num_exist_int, num_exist_int + additional_ints):
+        for i in range(num_existing_moving, num_existing_moving + additional_moving):
             shot = shotnumber_to_letter(i)
             print(f"📸 MovingImage {shot} for {moving_artist['username']}")
             moving_shot_name = f"{projnumber}_MovingImage_{shot}"
